Function emerald_std::io::syscall_get_file_meta
source · pub unsafe fn syscall_get_file_meta(
fd: usize,
meta: &mut FileMeta
) -> Result<(), SyscallError>Expand description
Safety
This function assumes that fd is a valid file descriptor.
The data in meta will be ignored, only the type is important here